@@ -1,11 +1,13 @@
 #
-# $Id: Metabrik.pm,v 647ee0932767 2015/11/21 16:42:55 gomor $
+# $Id: Metabrik.pm,v 1418b1e3b32f 2016/01/02 17:46:47 gomor $
 #
 package Metabrik;
 use strict;
 use warnings;
 
-our $VERSION = '1.11';
+# Breaking.Feature.Fix
+our $VERSION = '1.20';
+our $FIX = '0';
 
 use base qw(Class::Gomor::Hash);
 
@@ -25,7 +27,7 @@ sub brik_version {
    my $revision = $self->brik_properties->{revision};
    $revision =~ s/^.*\s([a-f0-9]+)\s.*$/$1/;
 
-   return $VERSION.'.'.$revision;
+   return $VERSION.'.'.$FIX.'-'.$revision;
 }
 
 sub brik_author {
@@ -48,10 +50,10 @@ sub brik_license {
 
 sub brik_properties {
    return {
-      revision => '$Revision: 647ee0932767 $',
+      revision => '$Revision: 1418b1e3b32f $',
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
-      tags => [ qw() ],
+      tags => [ ],
       attributes => {
          debug => [ qw(0|1) ],
          init_done => [ qw(0|1) ],
@@ -87,21 +89,32 @@ sub brik_properties {
          brik_inherited_attributes => [ ],  # Return only inherited Attributes
          brik_own_attributes => [ ],        # Return only own Attributes
          brik_has_attribute => [ qw(Attribute) ],
+         brik_preinit => [ qw(Arguments) ],
+         brik_init => [ qw(Arguments) ],
          brik_self => [ ],
+         brik_fini => [ qw(Arguments) ],
          brik_create_attributes => [ ],
          brik_set_default_attributes => [ ],
          brik_check_require_modules => [ ],
-         brik_check_require_used => [ ],
          brik_check_require_binaries => [ ],
          brik_check_properties => [ ],
+         brik_checks => [ ],
          brik_has_binary => [ qw(binary) ],
          brik_has_module => [ qw(module) ],
+         brik_help_run_undef_arg => [ qw(Command Arg) ],
+         brik_help_set_undef_arg => [ qw(Command Arg) ],
+         brik_help_run_invalid_arg => [ qw(Command Arg valid_list) ],
+         brik_help_run_empty_array_arg => [ qw(Command Arg) ],
+         brik_help_run_file_not_found => [ qw(Command Arg) ],
+         brik_help_run_directory_not_found => [ qw(Command Arg) ],
+         brik_help_run_must_be_root => [ qw(Command) ],
       },
       require_modules => { },
       optional_modules => { },
-      require_used => { },
       require_binaries => { },
       optional_binaries => { },
+      need_packages => { },
+      need_services => { },
    };
 }
 
@@ -309,9 +322,10 @@ sub brik_check_properties {
       commands => 1,
       require_modules => 1,
       optional_modules => 1,
-      require_used => 1,
       require_binaries => 1,
       optional_binaries => 1,
+      need_packages => 1,
+      need_services => 1,
    );
    for my $key (keys %$properties) {
       if (! exists($valid_keys{$key})) {
@@ -406,9 +420,10 @@ sub brik_check_use_properties {
       commands => 1,
       require_modules => 1,
       optional_modules => 1,
-      require_used => 1,
       require_binaries => 1,
       optional_binaries => 1,
+      need_packages => 1,
+      need_services => 1,
    );
    for my $key (keys %$use_properties) {
       if (! exists($valid_keys{$key})) {
@@ -445,10 +460,8 @@ sub brik_check_use_properties {
    return 1;
 }
 
-sub new {
-   my $self = shift->SUPER::new(
-      @_,
-   );
+sub brik_checks {
+   my $self = shift;
 
    my $r = $self->brik_check_properties;
    return unless $r;
@@ -459,13 +472,34 @@ sub new {
    $r = $self->brik_check_require_modules;
    return unless $r;
 
-   $r = $self->brik_check_require_used;
-   return unless $r;
-
    $r = $self->brik_check_require_binaries;
    return unless $r;
 
-   $r = $self->brik_create_attributes;
+   return $self;
+}
+
+sub new {
+   my $self = shift->SUPER::new(
+      @_,
+   );
+
+   my $r = $self->brik_create_attributes;
+   return unless $r;
+
+   $r = $self->brik_set_default_attributes;
+   return unless $r;
+
+   $self->brik_checks or return;
+
+   return $self->brik_preinit;
+}
+
+sub new_no_checks {
+   my $self = shift->SUPER::new(
+      @_,
+   );
+
+   my $r = $self->brik_create_attributes;
    return unless $r;
 
    $r = $self->brik_set_default_attributes;
@@ -483,15 +517,36 @@ sub new_from_brik {
    }
 
    my $log = $brik->log;
-   my $global = $brik->global;
-   my $context = $brik->context;
-   my $shell = $brik->shell;
+   my $glo = $brik->global;
+   my $con = $brik->context;
+   my $she = $brik->shell;
 
    return $self->new(
       log => $log,
-      global => $global,
-      context => $context,
-      shell => $shell,
+      global => $glo,
+      context => $con,
+      shell => $she,
+   );
+}
+
+sub new_from_brik_no_checks {
+   my $self = shift;
+   my ($brik) = @_;
+
+   if (! defined($brik)) {
+      return $self->_log_error("new_from_brik_no_checks: you must give a Brik object as argument");
+   }
+
+   my $log = $brik->log;
+   my $glo = $brik->global;
+   my $con = $brik->context;
+   my $she = $brik->shell;
+
+   return $self->new_no_checks(
+      log => $log,
+      global => $glo,
+      context => $con,
+      shell => $she,
    );
 }
 
@@ -506,6 +561,17 @@ sub new_from_brik_init {
    return $brik;
 }
 
+sub new_from_brik_init_no_checks {
+   my $self = shift;
+
+   my $brik = $self->new_from_brik_no_checks(@_)
+      or return $self->_log_error("new_from_brik_init_no_checks: new_from_brik_no_checks failed");
+   $brik->brik_init
+      or return $self->_log_error("new_from_brik_init_no_checks: brik_init failed");
+
+   return $brik;
+}
+
 # Build Attributes, Class::Gomor style
 sub brik_create_attributes {
    my $self = shift;
@@ -593,7 +659,7 @@ sub brik_check_require_modules {
          if ($@) {
             chomp($@);
             $self->_log_error("brik_check_require_modules: you have to install ".
-               "Module [$module]");
+               "module [$module]");
             $self->_log_debug("brik_check_require_modules: $@");
             $error++;
             next;
@@ -605,7 +671,7 @@ sub brik_check_require_modules {
             if ($@) {
             chomp($@);
                $self->_log_error("brik_check_require_modules: unable to import ".
-                  "functions [@imports] from Module [$module]");
+                  "functions [@imports] from module [$module]");
                $self->_log_debug("brik_check_require_modules: $@");
                $error++;
                next;
@@ -617,57 +683,6 @@ sub brik_check_require_modules {
    return $error ? 0 : 1;
 }
 
-sub brik_check_require_used {
-   my $self = shift;
-   my ($require_used) = @_;
-
-   # Not all modules are capable of checking context against used briks
-   # For instance, core::context Brik itselves.
-   my $context = $self->context;
-   if (! defined($context) || ! $context->can('used')) {
-      return 1;
-   }
-
-   my @require_used_list = ();
-   if (defined($require_used)) {
-      push @require_used_list, $require_used;
-   }
-   else {
-      my $classes = $self->brik_classes;
-      for my $class (@$classes) {
-         push @require_used_list, $class->brik_properties->{require_used};
-      }
-   }
-
-   my $used = $context->used;
-
-   my $error = 0;
-   for my $require_used (@require_used_list) {
-      for my $brik (keys %$require_used) {
-         next if $context->is_used($brik);
-
-         if ($self->global->auto_use_on_require) {
-            my $r = $context->use($brik);
-            if (! $r) {
-               $self->_log_warning("brik_check_require_used: use: Brik [$brik] failed");
-               $error++;
-               next;
-            }
-            else {
-               $self->_log_verbose("brik_check_require_used: use: Brik [$brik] success");
-            }
-         }
-         else {
-            $self->_log_error("brik_check_require_used: you must use Brik [$brik] first");
-            $error++;
-            next;
-         }
-      }
-   }
-
-   return $error ? 0 : 1;
-}
-
 sub brik_check_require_binaries {
    my $self = shift;
    my ($require_binaries) = @_;
@@ -828,7 +843,7 @@ sub brik_commands {
             next unless $command =~ /^[a-z]/; # Brik Commands always begin with a minuscule
             next if $command =~ /^cg[A-Z]/; # Class::Gomor stuff
             next if $command =~ /^_/; # Internal stuff
-            next if $command =~ /^(?:a|b|import|brik_init|brik_preinit|brik_fini|new|SUPER::|BEGIN|isa|can|EXPORT|AA|AS|ISA|DESTROY|__ANON__)$/; # Perl stuff
+            next if $command =~ /^(?:a|b|import|new|SUPER::|BEGIN|isa|can|EXPORT|AA|AS|ISA|DESTROY|__ANON__)$/; # Perl stuff
 
             #$self->_log_info("command[$command]");
 
@@ -850,7 +865,7 @@ sub brik_base_commands {
       next unless $command =~ /^[a-z]/; # Brik Commands always begin with a minuscule
       next if $command =~ /^cg[A-Z]/; # Class::Gomor stuff
       next if $command =~ /^_/; # Internal stuff
-      next if $command =~ /^(?:a|b|import|brik_init|brik_preinit|brik_fini|new|SUPER::|BEGIN|isa|can|EXPORT|AA|AS|ISA|DESTROY|__ANON__)$/; # Perl stuff
+      next if $command =~ /^(?:a|b|import|new|SUPER::|BEGIN|isa|can|EXPORT|AA|AS|ISA|DESTROY|__ANON__)$/; # Perl stuff
 
       #$self->_log_info("command[$command]");
 
@@ -877,7 +892,7 @@ sub brik_inherited_commands {
             next unless $command =~ /^[a-z]/; # Brik Commands always begin with a minuscule
             next if $command =~ /^cg[A-Z]/; # Class::Gomor stuff
             next if $command =~ /^_/; # Internal stuff
-            next if $command =~ /^(?:a|b|import|brik_init|brik_preinit|brik_fini|new|SUPER::|BEGIN|isa|can|EXPORT|AA|AS|ISA|DESTROY|__ANON__)$/; # Perl stuff
+            next if $command =~ /^(?:a|b|import|new|SUPER::|BEGIN|isa|can|EXPORT|AA|AS|ISA|DESTROY|__ANON__)$/; # Perl stuff
 
             $commands->{$command} = $class->brik_properties->{commands}->{$command};
          }
@@ -898,7 +913,7 @@ sub brik_own_commands {
          next unless $command =~ /^[a-z]/; # Brik Commands always begin with a minuscule
          next if $command =~ /^cg[A-Z]/; # Class::Gomor stuff
          next if $command =~ /^_/; # Internal stuff
-         next if $command =~ /^(?:a|b|import|brik_init|brik_preinit|brik_fini|new|SUPER::|BEGIN|isa|can|EXPORT|AA|AS|ISA|DESTROY|__ANON__)$/; # Perl stuff
+         next if $command =~ /^(?:a|b|import|new|SUPER::|BEGIN|isa|can|EXPORT|AA|AS|ISA|DESTROY|__ANON__)$/; # Perl stuff
 
          #$self->_log_info("command[$command]");
 
@@ -1111,6 +1126,114 @@ sub brik_fini {
    return $self;
 }
 
+sub brik_help_run_undef_arg {
+   my $self = shift;
+   my ($command, $argument) = @_;
+
+   my ($package, $filename, $line) = caller();
+   my $brik = lc($package);
+   $brik =~ s/^metabrik:://;
+
+   if (! defined($argument)) {
+      return $self->log->error("$brik: ".$self->brik_help_run($command));
+   }
+
+   return 1;
+}
+
+sub brik_help_set_undef_arg {
+   my $self = shift;
+   my ($command, $argument) = @_;
+
+   my ($package, $filename, $line) = caller();
+   my $brik = lc($package);
+   $brik =~ s/^metabrik:://;
+
+   if (! defined($argument)) {
+      return $self->log->error("$brik: ".$self->brik_help_set($command));
+   }
+
+   return 1;
+}
+
+sub brik_help_run_invalid_arg {
+   my $self = shift;
+   my ($command, $argument, @values) = @_;
+
+   my ($package, $filename, $line) = caller();
+   my $brik = lc($package);
+   $brik =~ s/^metabrik:://;
+
+   my $ref = ref($argument) || 'SCALAR';
+   my $values = { map { $_ => 1 } @values };
+   if (! exists($values->{$ref})) {
+      my $ok = join(', ', @values);
+      return $self->log->error("$brik: $command: invalid Argument [$argument], must be from [$ok]");
+   }
+
+   return $ref;
+}
+
+sub brik_help_run_empty_array_arg {
+   my $self = shift;
+   my ($command, $argument) = @_;
+
+   my ($package, $filename, $line) = caller();
+   my $brik = lc($package);
+   $brik =~ s/^metabrik:://;
+
+   if (@$argument <= 0) {
+      return $self->log->error("$brik: $command: ARRAY Argument [$argument] is empty");
+   }
+
+   return 1;
+}
+
+sub brik_help_run_file_not_found {
+   my $self = shift;
+   my ($command, $argument) = @_;
+
+   my ($package, $filename, $line) = caller();
+   my $brik = lc($package);
+   $brik =~ s/^metabrik:://;
+
+   if (! -f $argument) {
+      return $self->log->error("$brik: $command: file Argument [$argument] not found");
+   }
+
+   return 1;
+}
+
+sub brik_help_run_directory_not_found { 
+   my $self = shift;
+   my ($command, $argument) = @_;
+
+   my ($package, $filename, $line) = caller();
+   my $brik = lc($package);
+   $brik =~ s/^metabrik:://;
+
+   if (! -d $argument) {
+      return $self->log->error("$brik: $command: directory Argument [$argument] not found"); 
+   }
+
+   return 1;
+}
+
+sub brik_help_run_must_be_root {
+   my $self = shift;
+   my ($command) = @_;
+
+   my ($package, $filename, $line) = caller();
+   my $brik = lc($package);
+   $brik =~ s/^metabrik:://;
+
+   if ($< != 0) {
+      return $self->log->error("$brik: $command: must be root to run Command [$command]"); 
+   }
+
+   return 1;
+}
+
 1;
 
 __END__
@@ -1119,9 +1242,139 @@ __END__
 
 Metabrik - There is Brik for that.
 
+=head1 SYNOPSIS
+
+   use base qw(Metabrik);
+
+=head1 DESCRIPTION
+
+This is the B<Metabrik> Superclass. Every Brik derives from this one at the very least.
+
+=head1 ATTRIBUTES
+
+At B<The Metabrik Shell>, just type:
+
+L<get core::global>
+
+=head1 COMMANDS
+
+At B<The Metabrik Shell>, just type:
+
+L<help core::global>
+
+=head1 METHODS
+
+=over 4
+
+=item B<brik_properties>
+
+=item B<brik_use_properties>
+
+=item B<new>
+
+=item B<new_from_brik>
+
+=item B<new_from_brik_init>
+
+=item B<new_no_checks>
+
+=item B<new_from_brik_no_checks>
+
+=item B<new_from_brik_init_no_checks>
+
+=item B<brik_self>
+
+=item B<brik_preinit>
+
+=item B<brik_init>
+
+=item B<brik_attributes>
+
+=item B<brik_author>
+
+=item B<brik_category>
+
+=item B<brik_class>
+
+=item B<brik_classes>
+
+=item B<brik_commands>
+
+=item B<brik_license>
+
+=item B<brik_name>
+
+=item B<brik_tags>
+
+=item B<brik_version>
+
+=item B<brik_base_attributes>
+
+=item B<brik_base_commands>
+
+=item B<brik_check_properties>
+
+=item B<brik_check_require_binaries>
+
+=item B<brik_check_require_modules>
+
+=item B<brik_check_use_properties>
+
+=item B<brik_checks>
+
+=item B<brik_create_attributes>
+
+=item B<brik_has_attribute>
+
+=item B<brik_has_binary>
+
+=item B<brik_has_command>
+
+=item B<brik_has_module>
+
+=item B<brik_has_tag>
+
+=item B<brik_help_run>
+
+=item B<brik_help_run_directory_not_found>
+
+=item B<brik_help_run_empty_array_arg>
+
+=item B<brik_help_run_file_not_found>
+
+=item B<brik_help_run_must_be_root>
+
+=item B<brik_help_run_invalid_arg>
+
+=item B<brik_help_run_undef_arg>
+
+=item B<brik_help_set_undef_arg>
+
+=item B<brik_help_set>
+
+=item B<brik_inherited_attributes>
+
+=item B<brik_inherited_commands>
+
+=item B<brik_own_attributes>
+
+=item B<brik_own_commands>
+
+=item B<brik_repository>
+
+=item B<brik_set_default_attributes>
+
+=item B<brik_fini>
+
+=back
+
+=head1 SEE ALSO
+
+L<Metabrik>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
