@@ -1,22 +1,25 @@
 #
-# $Id: Context.pm,v 647ee0932767 2015/11/21 16:42:55 gomor $
+# $Id: Context.pm,v 1418b1e3b32f 2016/01/02 17:46:47 gomor $
 #
 package Metabrik::Core::Context;
 use strict;
 use warnings;
 
-our $VERSION = '1.11';
+# Breaking.Feature.Fix
+our $VERSION = '1.20';
+our $FIX = '0';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 647ee0932767 $',
-      tags => [ qw(core context main) ],
+      revision => '$Revision: 1418b1e3b32f $',
+      tags => [ qw(main core) ],
       attributes => {
          _lp => [ qw(INTERNAL) ],
       },
       commands => {
+         new_brik_run => [ qw(Brik Command Args) ],
          use => [ qw(Brik) ],
          set => [ qw(Brik Attribute Value) ],
          get => [ qw(Brik Attribute) ],
@@ -39,8 +42,9 @@ sub brik_properties {
          restore_state => [ qw(Brik) ],
       },
       require_modules => {
-         'Lexical::Persistence' => [ ],
+         'Data::Dump' => [ qw(dump) ],
          'File::Find' => [ ],
+         'Lexical::Persistence' => [ ],
          'Module::Reload' => [ ],
          'Metabrik::Core::Global' => [ ],
          'Metabrik::Core::Log' => [ ],
@@ -151,6 +155,22 @@ sub new {
    return $self->brik_preinit;
 }
 
+sub new_brik_run {
+   my $self = shift;
+   my ($brik, $command, @args) = @_;
+
+   my $con = Metabrik::Core::Context->new or return;
+
+   $con->use($brik) or return;
+   my $data = $con->run($brik, $command, @args) or return;
+   $con->brik_fini;
+
+   # Compatibility with file::dump Brik
+   print Data::Dump::dump($data)."\n";
+
+   return $con;
+}
+
 sub brik_init {
    my $self = shift;
 
@@ -626,7 +646,24 @@ sub set {
          die("$MSG\n");
       }
 
-      if ($__ctx_value =~ /^\$\w+/) {
+      # Support variable lookups like '$array' as an Argument
+      # Example: set <Brik> <Attribute> $Arg
+      if ($__ctx_value =~ /^\$\w+/ || $__ctx_value =~ /^\@\$\w+/
+      ||  $__ctx_value =~ /^\@\w+/ || $__ctx_value =~ /^\%\$\w+/
+      ||  $__ctx_value =~ /^\%\w+/) {
+         eval {
+            $__ctx_value = $CON->_lp->do($__ctx_value);
+         };
+         if ($@) {
+            chomp($@);
+            $ERR = 1;
+            my $MSG = "set: Brik [$__ctx_brik] has invalid argument [$__ctx_value]";
+            die("$MSG\n");
+         }
+      }
+      # Support passing ARRAYs or HASHs or Perl code as an Argument
+      # Example: set <Brik> <Attribute> "[ qw(a b c) ]"
+      elsif ($__ctx_value =~ /^\[.*\]$/ || $__ctx_value =~ /^\{.*\}$/) {
          eval {
             $__ctx_value = $CON->_lp->do($__ctx_value);
          };
@@ -736,7 +773,7 @@ sub run {
       for (@__ctx_args) {
          # Support variable lookups like '$array' as an Argument
          # Example: run <Brik> <Command> $Arg1 Arg2
-         if (/^\$\w+/) {
+         if (/^\$\w+/ || /^\@\$\w+/ || /^\@\w+/ || /^\%\$\w+/ || /^\%\w+/) {
             eval {
                $_ = $CON->_lp->do($_);
             };
@@ -867,9 +904,95 @@ __END__
 
 Metabrik::Core::Context - core::context Brik
 
+=head1 SYNOPSIS
+
+   use Metabrik::Core::Context;   
+
+   my $CON = Metabrik::Core::Context->new or die("core::context");
+
+=head1 DESCRIPTION
+
+This Brik keeps track of everything that happens within B<Metabrik>. That includes persistence of Perl variables and loaded Briks along with their set Attributes for instance.
+
+This is the only Brik that is mandatory to B<use> when writing a Tool, and it will auto-load B<core::log>, B<core::global> and B<core::shell> for you. When these Briks are loaded from B<core::context>, some global variables are set as pointers to them: B<$CON>, B<$GLO>, B<$LOG>, and B<$SHE> to point to respectively B<core::context>, B<core::global>, B<core::log> and B<core::shell> Briks.
+
+=head1 ATTRIBUTES
+
+At B<The Metabrik Shell>, just type:
+
+L<get core::context>
+
+=head1 COMMANDS
+
+At B<The Metabrik Shell>, just type:
+
+L<help core::context>
+
+=head1 METHODS
+
+=over 4
+
+=item B<brik_properties>
+
+=item B<new>
+
+=item B<new_brik_run>
+
+=item B<brik_init>
+
+=item B<available>
+
+=item B<call>
+
+=item B<do>
+
+=item B<find_available>
+
+=item B<get>
+
+=item B<get_used>
+
+=item B<is_available>
+
+=item B<is_not_used>
+
+=item B<is_used>
+
+=item B<log>
+
+=item B<not_used>
+
+=item B<restore_state>
+
+=item B<reuse>
+
+=item B<run>
+
+=item B<save_state>
+
+=item B<set>
+
+=item B<status>
+
+=item B<update_available>
+
+=item B<use>
+
+=item B<used>
+
+=item B<variables>
+
+=item B<brik_fini>
+
+=back
+
+=head1 SEE ALSO
+
+L<Metabrik>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
