@@ -1,5 +1,5 @@
 #
-# $Id: Log.pm,v ff2fda66d776 2015/11/10 09:20:39 gomor $
+# $Id: Log.pm,v 1418b1e3b32f 2016/01/02 17:46:47 gomor $
 #
 # core::log Brik
 #
@@ -7,14 +7,16 @@ package Metabrik::Core::Log;
 use strict;
 use warnings;
 
-our $VERSION = '1.11';
+# Breaking.Feature.Fix
+our $VERSION = '1.20';
+our $FIX = '0';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: ff2fda66d776 $',
-      tags => [ qw(core main log) ],
+      revision => '$Revision: 1418b1e3b32f $',
+      tags => [ qw(main core) ],
       attributes => {
          color => [ qw(0|1) ],
          level => [ qw(0|1|2|3) ],
@@ -175,9 +177,55 @@ __END__
 
 Metabrik::Core::Log - core::log Brik
 
+=head1 SYNOPSIS
+
+   use Metabrik::Core::Log;
+
+   my $LOG = Metabrik::Core::Log->new;
+
+=head1 DESCRIPTION
+
+This Brik is the default logging mechanism: output on console. You could write a different logging Brik as long as it respects the API as described in the B<METHODS> paragraph below. You don't need to use this Brik directly. It is auto-loaded by B<core::context> Brik and is stored in its B<log> Attribute.
+
+=head1 ATTRIBUTES
+
+At B<The Metabrik Shell>, just type:
+
+L<get core::log>
+
+=head1 COMMANDS
+
+At B<The Metabrik Shell>, just type:
+
+L<help core::log>
+
+=head1 METHODS
+
+=over 4
+
+=item B<brik_properties>
+
+=item B<debug>
+
+=item B<error>
+
+=item B<fatal>
+
+=item B<info>
+
+=item B<verbose>
+
+=item B<warning>
+
+=back
+
+=head1 SEE ALSO
+
+L<Metabrik>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
