@@ -1,5 +1,5 @@
 #
-# $Id: Shell.pm,v 647ee0932767 2015/11/21 16:42:55 gomor $
+# $Id: Shell.pm,v 1418b1e3b32f 2016/01/02 17:46:47 gomor $
 #
 # core::shell Brik
 #
@@ -7,7 +7,9 @@ package Metabrik::Core::Shell;
 use strict;
 use warnings;
 
-our $VERSION = '1.11';
+# Breaking.Feature.Fix
+our $VERSION = '1.20';
+our $FIX = '0';
 
 use base qw(Term::Shell Metabrik);
 
@@ -15,8 +17,8 @@ use IO::All;
 
 sub brik_properties {
    return {
-      revision => '$Revision: 647ee0932767 $',
-      tags => [ qw(core main shell) ],
+      revision => '$Revision: 1418b1e3b32f $',
+      tags => [ qw(main core) ],
       attributes => {
          echo => [ qw(0|1) ],
          help_show_base_attributes => [ qw(0|1) ],
@@ -266,6 +268,9 @@ sub AUTOLOAD {
          return $self->cmd(join(' ', $cmd, @args));
       }
    }
+   else {
+      $self->log->verbose("AUTOLOAD: Brik [shell::command] not loaded, skipping");
+   }
 
    return 1;
 }
@@ -582,14 +587,14 @@ sub run_alias {
    if (! defined($alias)) {
       for my $this (sort { $a cmp $b } keys %$aliases) {
          ($alias = $this) =~ s/^run_//;
-         $self->log->info(sprintf("%-10s \"%s\"", $alias, $aliases->{$this}));
+         printf("alias %-10s \"%s\"\n", $alias, $aliases->{$this});
       }
 
       return 1;
    }
    elsif (length($alias) && @cmd == 0) {
       $alias =~ s/^run_//;
-      $self->log->info(sprintf("%-10s \"%s\"", $alias, $aliases->{"run_$alias"}));
+      printf("alias %-10s \"%s\"\n", $alias, $aliases->{"run_$alias"});
 
       return 1;
    }
@@ -616,21 +621,21 @@ sub run_cd {
    my ($dir, @args) = @_;
 
    if (defined($dir)) {
-      if ($dir =~ /^~$/) {
+      if ($dir =~ m{^~}) {
          #$dir = $self->path_home;
-         $dir = $self->{path_home};
+         $dir =~ s{^~}{$self->{path_home}};
       }
       if (! -d $dir) {
-         return $self->log->error("cd: $dir: can't cd to this");
+         return $self->log->error("cd: directory [$dir] does not exist");
       }
       chdir($dir)
-         or return $self->log->error("cd: $dir: $!");
+         or return $self->log->error("cd: chdir failed for directory [$dir]: $!");
       $self->_update_path_cwd;
    }
    else {
       #chdir($self->path_home);
       chdir($self->{path_home})
-         or return $self->log->error("cd: $dir: $!");
+         or return $self->log->error("cd: chdir failed for directory [$dir]: $!");
       $self->_update_path_cwd;
    }
 
@@ -1321,12 +1326,16 @@ sub catch_run {
    my $self = shift;
    my (@args) = @_;
 
+   my $context = $self->context;
+
    $self->debug && $self->log->debug("catch_run: args [@args]");
 
    # If it starts with a '/', we really want to 'run shell::command system'
-   if (defined($args[0]) && $args[0] =~ m{/}) {
-      my $cmd = "run shell::command system";
-      return $self->cmd(join(' ', $cmd, @args));
+   if ($context->is_used('shell::command')) {
+      if (defined($args[0]) && $args[0] =~ m{^\s*/}) {
+         my $cmd = "run shell::command system";
+         return $self->cmd(join(' ', $cmd, @args));
+      }
    }
 
    # Default to execute Perl commands
@@ -1408,14 +1417,14 @@ sub catch_comp_sub {
    my $count = scalar(@words);
    my $last = $words[-1];
 
-   $self->debug && $self->log->debug("catch_comp: words[@words] | word[$word] line[$line] start[$start] | last[$last]");
+   $self->debug && $self->log->debug("catch_comp_sub: words[@words] | word[$word] line[$line] start[$start] | last[$last]");
 
    # Be default, we will read the current directory
    if (! length($word)) {
       $word = '.';
    }
 
-   $self->debug && $self->log->debug("catch_comp: DEFAULT: words[@words] | word[$word] line[$line] start[$start] | last[$last]");
+   $self->debug && $self->log->debug("catch_comp_sub: DEFAULT: words[@words] | word[$word] line[$line] start[$start] | last[$last]");
 
    my @comp = ();
 
@@ -1455,6 +1464,14 @@ sub catch_comp_sub {
       }
    }
 
+   # If there are some whitespace, we put between quotes
+   for (@comp) {
+      if (m{\s+}) {
+         s/^/"/;
+         s/$/"/;
+      }
+   }
+
    return @comp;
 }
 
@@ -1531,6 +1548,14 @@ sub catch_comp {
       }
    }
 
+   # If there are some whitespace, we put between quotes
+   for (@comp) {
+      if (m{\s+}) {
+         s/^/"/;
+         s/$/"/;
+      }
+   }
+
    $self->debug && $self->log->debug("catch_comp: possible [@comp]");
 
    return @comp;
@@ -1544,9 +1569,123 @@ __END__
 
 Metabrik::Core::Shell - core::shell Brik
 
+=head1 SYNOPSIS
+
+   use Metabrik::Core::Shell;
+
+   my $SHE = Metabrik::Core::Shell->new;
+
+=head1 DESCRIPTION 
+
+This Brik is B<The Metabrik Shell>, where you will be able to play with B<use>, B<set>, B<get> and B<run> Commands from available Briks. You don't need to use this Brik directly. It is auto-loaded by B<core::context> Brik and is stored in its B<shell> Attribute.
+
+=head1 ATTRIBUTES
+
+At B<The Metabrik Shell>, just type:
+
+L<get core::shell>
+
+=head1 COMMANDS
+
+At B<The Metabrik Shell>, just type:
+
+L<help core::shell>
+
+=head1 METHODS
+
+=over 4
+
+=item B<brik_properties>
+
+=item B<brik_init>
+
+=item B<catch_comp>
+
+=item B<catch_comp_sub>
+
+=item B<catch_run>
+
+=item B<cmd_is_complete>
+
+=item B<cmd_to_code>
+
+=item B<cmdloop>
+
+=item B<comp_alias>
+
+=item B<comp_cd>
+
+=item B<comp_code>
+
+=item B<comp_exit>
+
+=item B<comp_get>
+
+=item B<comp_help>
+
+=item B<comp_run>
+
+=item B<comp_set>
+
+=item B<comp_use>
+
+=item B<get_available_help>
+
+=item B<get_comp_attributes>
+
+=item B<get_comp_commands>
+
+=item B<get_help_attributes>
+
+=item B<get_help_commands>
+
+=back
+
+=head1 PRIVATE METHODS
+
+=over 4
+
+=item B<new>
+
+=item B<init>
+
+=item B<splash>
+
+=item B<process_line>
+
+=item B<pwd>
+
+=item B<prompt_str>
+
+=item B<rl_complete>
+
+=item B<run_alias>
+
+=item B<run_cd>
+
+=item B<run_code>
+
+=item B<run_exit>
+
+=item B<run_get>
+
+=item B<run_help>
+
+=item B<run_run>
+
+=item B<run_set>
+
+=item B<run_use>
+
+=back
+
+=head1 SEE ALSO
+
+L<Metabrik>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
